"""
>>> from testing import CLITesting, diff; cli = CLITesting(__name__)

>>> cli.run("python cars.py data/auta.csv data/auta-output.json")

Srovnání s očekávaným výstupním souborem:
>>> diff("data/auta-expected.json", "data/auta-output.json")
Files are identical

"""


def try_int(string: str) -> str|int:
    try:
        return int(string)
    except ValueError:
        return string


def main() -> None:
    import csv
    import json
    from argparse import ArgumentParser
    from pathlib import Path
    parser = ArgumentParser()
    parser.add_argument('input', help='Input CSV file', type=Path)
    parser.add_argument('output', help='Output JSON file', type=Path)
    args = parser.parse_args()
    result = {}
    with open(args.input, encoding='utf8', newline='') as r:
        reader = csv.DictReader(r)
        for row in reader:
            model = row['Model']
            result[model] = {key: try_int(value) for key, value in row.items()}
    with open(args.output, 'w', encoding='utf8') as w:
        json.dump(result, w, indent=4, ensure_ascii=False)


if __name__ == '__main__':
    main()
