"""
>>> from testing import CLITesting, diff; cli = CLITesting(__name__)

>>> cli.run("python minmax.py data/table1.csv data/minmax1.csv")

Srovnání s očekávaným výstupním souborem:
>>> diff("data/minmax1-expected.csv", "data/minmax1.csv")
Files are identical

>>> cli.run("python minmax.py data/table2.csv data/minmax2.csv")

Srovnání s očekávaným výstupním souborem:
>>> diff("data/minmax2-expected.csv", "data/minmax2.csv")
Files are identical

>>> cli.run("python minmax.py data/table3.csv data/minmax3.csv --header --delimiter ';'")

Srovnání s očekávaným výstupním souborem:
>>> diff("data/minmax3-expected.csv", "data/minmax3.csv")
Files are identical
"""


def main() -> None:
    from argparse import ArgumentParser
    from pathlib import Path
    parser = ArgumentParser()
    parser.add_argument('input', help='Input CSV file', type=Path)
    parser.add_argument('output', help='Output CSV file', type=Path)
    parser.add_argument('-H', '--header', help='Interpret the first line as column names', action='store_true')
    parser.add_argument('-d', '--delimiter', help='Delimiter in the CSV files', type=str, default=',')
    args = parser.parse_args()
    import csv
    with open(args.input, encoding='utf8') as f:
        header = f.readline() if args.header else None
        reader = csv.reader(f, delimiter=args.delimiter)
        table = list(reader)
    n_cols = len(table[0])
    minima = []
    maxima = []
    for i_col in range(n_cols):
        try:
            col = [float(row[i_col]) for row in table]
            mini = min(col)
            maxi = max(col)
        except ValueError:
            mini = ''
            maxi = ''
        minima.append(mini)
        maxima.append(maxi)
    with open(args.output, 'w', encoding='utf8') as f:
        if header is not None:
            print(header, file=f)
        writer = csv.writer(f, delimiter=args.delimiter)
        writer.writerow(minima)
        writer.writerow(maxima)


if __name__ == '__main__':
    main()
